import sys

import typer
from loguru import logger

from helpo.jira import Jira

app = typer.Typer()


@logger.catch
@app.command()
def create_project(key: str,
                   name: str,
                   description: str,
                   lead_account_id: str,
                   project_template_key: str,
                   assignee_type: str,
                   project_type_key: str,
                   jira_username: str = '',
                   jira_token: str = ''):
    jira_api = Jira(jira_username, jira_token)
    specs = {
        "key": key,
        "name": name,
        "description": description,
        "leadAccountId": lead_account_id,
        "projectTemplateKey": project_template_key,
        "assigneeType": assignee_type,
        "projectTypeKey": project_type_key
    }

    project_details = jira_api.create_project(specs)
    typer.echo(project_details)


@logger.catch
@app.command()
def delete_project(key: str,
                   jira_username: str = '',
                   jira_token: str = ''):
    jira_api = Jira(jira_username, jira_token)
    jira_api.delete_project(key)
    typer.echo('Success')


@logger.catch
@app.command()
def create_project_from_template(project_id: str, key: str,
                                 name: str, lead: str,
                                 jira_username: str = '',
                                 jira_token: str = ''):
    jira_api = Jira(jira_username, jira_token)
    project_info = jira_api.create_project_from_template(
        project_id, key, name, lead)
    if project_info:
        typer.echo(project_info)
    else:
        sys.exit(1)


if __name__ == "__main__":
    app()



import random
import string

import hvac
import hvac.exceptions
import jsonmerge
import yaml
import zx
from loguru import logger
from minio import Minio


class RemoteServer(object):
    def __init__(self, username: str, password: str,
                 ip: str, port: int, ssh_key: str = None):
        self.username = username
        self.password = password
        self.ip = ip
        self.port = port
        self.ssh_key = ssh_key
        self.hostname = None

    @logger.catch
    def add_to_rundeck(self, hostname: str,
                       vault_url: str,
                       vault_token: str,
                       vault_tenant: str,
                       minio_url: str,
                       minio_access_key: str,
                       minio_secret_key: str):

        self._enable_passwordless_sudo()
        self._update_hostname(hostname)
        self._add_sudo_user_with_ssh_key(
            'rundeck',
            'ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAACAQC+BjvvlnGkQSVeEd89u0OhZjWxEW+b+Wf7zSQZ663JZDdSZG6/+eqDeTx7wKasBwllmKtFQsCt3490BrebT2/75HdIO4AmoYnG/5OAqIRsNccFmTJIwCuZWM+vegjyFE4e3y9U+xgBLde+Y+CyRohoQnNCNv/92D5vVJgJ4uQbPpSXRcYqZgTHcekAUe8hO0a9Qk0GJxwjjFCwlOiWOTQgYZ4Hd+UdgXRmhMKQZTmMgXxpKdWZsoJ5Ay6Ebxf2LpDOMv5ErRDFBXW4k1gtzSAgpdsfkBKbWrUgm0dGmYT7Wx1RB87qq/6idhPKpV8QlzDi10sNC62RMb9wC0touOv5zZUeA2ruuHveRqfFt4Vo1aGBsqGbrCJVa6brkTBIYUq+w+ZHdlvnjxLxufbNwzodX3vzAmd0lt7YO/C+DBT0N/UMvGm7NH2lRdxJU7/LI5OY80MpdVAAZRvkzg9bmIB7a0ZZ4WLt/mELsZn8Jr1eExxeFGBl4POC0vmHKJxtndriyTtI/wt1JGlMPeilaW44FP9SwjSQcGy46vKOCTlzh13SvALXA9gMTnOUaLUGvprnSAOpkFNSBL6PZULNbEavFA8BNCrLGe3j7iTtaT8fCi3k2EFKagDs/lvkhLFM5RIXBxNLqFT51AlcWXq6bybdG0a7zyEJcXrWndnVUzkXIw== rundeck@ansible.zadapps.info')
        self._update_ssh_credentials(
            hostname, vault_tenant, vault_token, vault_url)
        self._update_rundeck_minio_nodes_file(minio_url, minio_access_key, minio_secret_key,
                                              '/tmp/infrastructure_s3_nodes.yaml',
                                              'rundeck.zadapps.info', 'infrastructure_s3_nodes.yaml')
        self._update_ansible_minio_inventory_file(minio_url, minio_access_key, minio_secret_key,
                                                  '/tmp/ansible_inventory.yaml',
                                                  'rundeck.zadapps.info', 'ansible_inventory.yaml')
        self.print_final_ssh_server_info()

    @logger.catch
    def _enable_passwordless_sudo(self):
        self._run_command(
            rf'''"echo '{self.password}' | sudo -S sed -i 's/^%sudo\sALL.*$/%sudo ALL=(ALL:ALL) NOPASSWD: ALL/g' /etc/sudoers"''')

    @logger.catch
    def _update_hostname(self, hostname: str):
        self._run_command(rf'''"sudo hostnamectl set-hostname {hostname}"''')
        self._run_command(
            rf'''"sudo sed -i 's/^127.0.1.1.*$/127.0.1.1 {hostname}/g' /etc/hosts"''')
        self.hostname = hostname

    @logger.catch
    def _add_sudo_user_with_ssh_key(self, username: str, public_ssh_key: str):
        self._run_command(
            rf'''"sudo useradd -m -s /bin/bash -G sudo {username}"''')
        self._run_command(rf'''"sudo mkdir -p /home/{username}/.ssh -m 0700 \
        && sudo chown -R {username}. /home/{username}/.ssh \
        && echo '{public_ssh_key}' | sudo tee /home/{username}/.ssh/authorized_keys \
        && sudo chmod 0600 /home/{username}/.ssh/authorized_keys \
        && sudo chown {username}. /home/{username}/.ssh/authorized_keys"''')

    @logger.catch
    def _read_vault_secret(self, vault_url: str, vault_token: str, path: str):
        vault_api_client = hvac.Client(url=vault_url, token=vault_token)
        return vault_api_client.secrets.kv.v2.read_secret_version(path)['data']['data']

    @logger.catch
    def _change_user_password(self, username: str, password: str):
        self._run_command(
            rf'''"echo -e '{password}\n{password}' | sudo passwd {username}"''')

    @logger.catch
    def _update_ssh_port(self, port: int):
        self._run_command(
            rf'''"sudo sed -i 's/^.*Port.*$/Port {port}/g' /etc/ssh/sshd_config"''')
        logger.info(f'ssh port updated to {port}')
        self._restart_systemd_service('sshd')
        logger.info(f'ssh service restarted')

    @logger.catch
    def _restart_systemd_service(self, name: str):
        self._run_command(rf'''"sudo systemctl restart {name}"''')

    @logger.catch
    def _write_vault_secret(self, vault_url: str, vault_token: str, path: str, secret: dict):
        vault_api_client = hvac.Client(url=vault_url, token=vault_token)
        return vault_api_client.secrets.kv.v2.create_or_update_secret(
            path=path,
            secret=secret)

    @logger.catch
    def _update_rundeck_minio_nodes_file(self, minio_url: str, access_key: str, secret_key: str,
                                         local_file_path: str, bucket: str, minio_file_name: str):
        api_client = Minio(minio_url, access_key, secret_key)
        api_client.fget_object(
            bucket, minio_file_name, local_file_path,
        )

        server_credentials = {self.hostname: {'hostname': f'{self.ip}:{self.port}',
                                              'nodename': self.hostname,
                                              'ssh-keypath': 'keys/ssh/ansible/privateKey',
                                              'sshport': self.port,
                                              'username': 'rundeck'}}
        self._merge_yaml_file_content_with_json_object(local_file_path,
                                                       server_credentials)
        self._put_file_to_minio(minio_url, access_key, secret_key,
                                local_file_path, bucket, minio_file_name)

    @logger.catch
    def _update_ansible_minio_inventory_file(self, minio_url: str, access_key: str, secret_key: str,
                                             local_file_path: str, bucket: str, minio_file_name: str):
        api_client = Minio(minio_url, access_key, secret_key)
        api_client.fget_object(
            bucket, minio_file_name, local_file_path,
        )

        server_credentials = {'all': {'hosts': {self.hostname: {'ansible_host': self.ip,
                                                                'ansible_port': self.port,
                                                                'ansible_user': 'rundeck'}}}}
        self._merge_yaml_file_content_with_json_object(local_file_path,
                                                       server_credentials)
        self._put_file_to_minio(minio_url, access_key, secret_key,
                                local_file_path, bucket, minio_file_name)

    @logger.catch
    def _merge_yaml_file_content_with_json_object(self, local_file_path: str,
                                                  json_object: dict):
        with open(local_file_path, 'r') as nodes_yaml_file:
            nodes_object = yaml.full_load(nodes_yaml_file)
            new_nodes_object = jsonmerge.merge(nodes_object, json_object)
        with open(local_file_path, 'w') as nodes_yaml_file:
            yaml.dump(new_nodes_object, nodes_yaml_file, allow_unicode=True)

    @logger.catch
    def _run_command(self, command: str, print_it: bool = 1):
        if not self.ssh_key:
            command_prefix = rf'''sshpass -p "{self.password
            }" ssh -o StrictHostKeyChecking=no {self.username}@{self.ip} -p {self.port}'''
            zx.run_shell(rf'''{command_prefix} {command}''', print_it)
        else:
            command_prefix = rf'''ssh -o StrictHostKeyChecking=no {
            self.username}@{self.ip} -i ~/.ssh/ansible -p {self.port}'''
            zx.run_shell(rf'''{command_prefix} {command}''', print_it)

    @logger.catch
    def _put_file_to_minio(self, url: str, access_key: str, secret_key: str,
                           local_file_path: str, bucket: str, minio_file_name: str):
        api_client = Minio(url, access_key, secret_key)
        api_client.fput_object(
            bucket, minio_file_name, local_file_path,
        )

    @logger.catch
    def _update_users_passwords(self, users: tuple, password: str):
        for ssh_user in users:
            self._change_user_password(ssh_user, password)

    @logger.catch
    def _update_ssh_credentials(self, hostname, vault_tenant, vault_token, vault_url):
        try:
            remote_server_ssh_info = self._read_vault_secret(vault_url,
                                                             vault_token,
                                                             f'tenant/{vault_tenant}/server/{hostname}/ssh')
            self._update_users_passwords(
                ('root', 'abukamel'), remote_server_ssh_info['password'])
            self._update_ssh_port(int(remote_server_ssh_info['port']))
            self.port = int(remote_server_ssh_info['port'])
            self.password = remote_server_ssh_info['password']
        except (Exception, hvac.exceptions.InvalidPath):
            print('Secret not found, creating vault secret')
            new_ssh_port = random.randrange(40000, 49999)
            new_ssh_password = ''.join(random.choice(
                string.ascii_letters + string.digits) for _ in range(32))
            self._update_users_passwords(
                ('root', 'abukamel'), new_ssh_password)
            self._update_ssh_port(new_ssh_port)
            self.port = new_ssh_port
            self.password = new_ssh_password
            self._write_vault_secret(vault_url,
                                     vault_token,
                                     path=f'tenant/{vault_tenant}/server/{hostname}/ssh',
                                     secret=dict(ip=self.ip,
                                                 password=self.password,
                                                 user='root',
                                                 port=str(self.port)))

    @logger.catch
    def _get_file_from_minio(self, url: str, access_key: str, secret_key: str,
                             local_file_path: str, bucket: str, minio_file_name: str):
        api_client = Minio(url, access_key, secret_key)
        api_client.fget_object(
            bucket, minio_file_name, local_file_path,
        )

    @logger.catch
    def print_final_ssh_server_info(self):
        print(
            'Copy and paste the following commands to add server to your local ssh config')
        print('command storm -v || pip3 install stormssh')
        print(
            rf'storm add --id_file="~/.ssh/id_ed25519" {self.hostname} {self.username}@{self.ip}:{self.port}')



import json
import os
import sys

import typer
from loguru import logger

from helpo.cloudflare import Cloudflare

app = typer.Typer()


@logger.catch
@app.command()
def purge_all_files(zone_name: str,
                    cf_email: str = os.environ.get('CF_API_EMAIL'),
                    cf_key: str = os.environ.get('CF_API_KEY')):
    cf_api = Cloudflare(cf_email, cf_key)
    purge_result = cf_api.purge_all_files(zone_name)
    if purge_result:
        typer.echo(purge_result)
    else:
        sys.exit(1)


@logger.catch
@app.command()
def purge_files_by_url(zone_name: str, urls: str,
                       cf_email: str = os.environ.get('CF_API_EMAIL'),
                       cf_key: str = os.environ.get('CF_API_KEY')):
    cf_api = Cloudflare(cf_email, cf_key)
    urls_list = urls.split(',')
    purge_result = cf_api.purge_files_by_url(zone_name, urls_list)
    if purge_result:
        typer.echo(purge_result)
    else:
        sys.exit(1)


@logger.catch
@app.command()
def get_dns_record_value(zone_name: str, fqdn: str,
                         cf_email: str = os.environ.get('CF_API_EMAIL'),
                         cf_key: str = os.environ.get('CF_API_KEY')):
    cf_api = Cloudflare(cf_email, cf_key)
    record = cf_api.get_dns_record_value(zone_name, fqdn)[0]
    if record:
        typer.echo(json.dumps(
            {'name': record['name'], 'content': record['content']}))
    else:
        sys.exit(1)


@logger.catch
@app.command()
def create_zone(zone_name: str, account_id: str,
                cf_email: str = os.environ.get('CF_API_EMAIL'),
                cf_key: str = os.environ.get('CF_API_KEY')):
    cf_api = Cloudflare(cf_email, cf_key)
    zone_info = cf_api.create_zone(zone_name, account_id)
    if zone_info:
        typer.echo(json.dumps(
            {'name': zone_info['name'], 'id': zone_info['id']}))
    else:
        sys.exit(1)


@logger.catch
@app.command()
def buy_new_domain(zone_name: str, account_id: str,
                   cf_email: str = os.environ.get('CF_API_EMAIL'),
                   cf_key: str = os.environ.get('CF_API_KEY')):
    cf_api = Cloudflare(cf_email, cf_key)
    zone_info = cf_api.buy_new_domain(account_id, zone_name)
    if zone_info and zone_info['available']:
        typer.echo(zone_info)
    else:
        typer.echo(f'unavailable domain: {zone_name}')
        sys.exit(1)


@logger.catch
@app.command()
def list_domains(account_id: str,
                 cf_email: str = os.environ.get('CF_API_EMAIL'),
                 cf_key: str = os.environ.get('CF_API_KEY')):
    cf_api = Cloudflare(cf_email, cf_key)
    zone_info = cf_api.list_domains(account_id)
    if zone_info:
        typer.echo(zone_info)
    else:
        sys.exit(1)


@logger.catch
@app.command()
def disable_dns_record_proxy(zone_name: str, fqdn: str,
                             cf_email: str = os.environ.get('CF_API_EMAIL'),
                             cf_key: str = os.environ.get('CF_API_KEY')):
    cf_api = Cloudflare(cf_email, cf_key)
    record = cf_api.disable_dns_record_proxy(zone_name, fqdn)
    if record:
        typer.echo(record)
    else:
        sys.exit(1)


@logger.catch
@app.command()
def enable_dns_record_proxy(zone_name: str, fqdn: str,
                            cf_email: str = os.environ.get('CF_API_EMAIL'),
                            cf_key: str = os.environ.get('CF_API_KEY')):
    cf_api = Cloudflare(cf_email, cf_key)
    record = cf_api.enable_dns_record_proxy(zone_name, fqdn)
    if record:
        typer.echo(record)
    else:
        sys.exit(1)


@logger.catch
@app.command()
def update_dns_record(zone_name: str, fqdn: str, value: str,
                      cf_email: str = os.environ.get('CF_API_EMAIL'),
                      cf_key: str = os.environ.get('CF_API_KEY')):
    cf_api = Cloudflare(cf_email, cf_key)
    record = cf_api.update_dns_record(zone_name, fqdn, value)
    if record:
        typer.echo(record)
    else:
        sys.exit(1)


if __name__ == "__main__":
    app()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['helpo']

package_data = \
{'': ['*']}

install_requires = \
['atlassian-python-api>=3.10.0,<4.0.0',
 'cloudflare>=2.8.15,<3.0.0',
 'hvac>=0.11.2,<0.12.0',
 'jsonmerge>=1.8.0,<2.0.0',
 'loguru>=0.5.3,<0.6.0',
 'minio>=7.0.3,<8.0.0',
 'namecom>=0.5.0,<0.6.0',
 'packaging>=21.3,<22.0',
 'requests>=2.25.1,<3.0.0',
 'slumber>=0.7.1,<0.8.0',
 'tenacity>=8.0.1,<9.0.0',
 'tldextract>=3.1.2,<4.0.0',
 'typer>=0.4.0,<0.5.0',
 'zxpy>=1.2.2,<2.0.0']

entry_points = \
{'console_scripts': ['helpo = helpo.main:app']}

setup_kwargs = {
    'name': 'helpo',
    'version': '0.1.24',
    'description': 'zg helper cli scripts',
    'long_description': '<!-- ABOUT THE PROJECT -->\n## About The Project\n\nHere\'s a blank template to get started: To avoid retyping too much info. Do a search and replace with your text editor for the following: `github_username`, `repo_name`, `twitter_handle`, `linkedin_username`, `email`, `email_client`, `project_title`, `project_description`\n\n### Built With\n\n* [Next.js](https://nextjs.org/)\n* [React.js](https://reactjs.org/)\n* [Vue.js](https://vuejs.org/)\n* [Angular](https://angular.io/)\n* [Svelte](https://svelte.dev/)\n* [Laravel](https://laravel.com)\n* [Bootstrap](https://getbootstrap.com)\n* [JQuery](https://jquery.com)\n\n## Getting Started\n\nThis is an example of how you may give instructions on setting up your project locally.\nTo get a local copy up and running follow these simple example steps.\n\n### Prerequisites\n\nThis is an example of how to list things you need to use the software and how to install them.\n* npm\n  ```sh\n  npm install npm@latest -g\n  ```\n\n### Installation\n\n1. Get a free API Key at [https://example.com](https://example.com)\n2. Clone the repo\n   ```sh\n   git clone https://github.com/github_username/repo_name.git\n   ```\n3. Install NPM packages\n   ```sh\n   npm install\n   ```\n4. Enter your API in `config.js`\n   ```js\n   const API_KEY = \'ENTER YOUR API\';\n   ```\n\n<!-- USAGE EXAMPLES -->\n## Usage\n\nUse this space to show useful examples of how a project can be used. Additional screenshots, code examples and demos work well in this space. You may also link to more resources.\n\n_For more examples, please refer to the [Documentation](https://example.com)_\n\n<!-- ROADMAP -->\n## Roadmap\n\n- [] Feature 1\n- [] Feature 2\n- [] Feature 3\n    - [] Nested Feature\n\nSee the [open issues](https://github.com/github_username/repo_name/issues) for a full list of proposed features (and known issues).\n\n<!-- CONTRIBUTING -->\n## Contributing\n\nContributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.\n\nIf you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".\nDon\'t forget to give the project a star! Thanks again!\n\n1. Fork the Project\n2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)\n3. Commit your Changes (`git commit -m \'Add some AmazingFeature\'`)\n4. Push to the Branch (`git push origin feature/AmazingFeature`)\n5. Open a Pull Request\n\n<!-- LICENSE -->\n## License\n\nDistributed under the MIT License. See `LICENSE.txt` for more information.\n\n<!-- CONTACT -->\n## Contact\n\nYour Name - [@twitter_handle](https://twitter.com/twitter_handle) - email@email_client.com\n\nProject Link: [https://github.com/github_username/repo_name](https://github.com/github_username/repo_name)\n\n<!-- ACKNOWLEDGMENTS -->\n## Acknowledgments\n\n* []()\n* []()\n* []()\n\n<!-- MARKDOWN LINKS & IMAGES -->\n<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->\n[contributors-shield]: https://img.shields.io/github/contributors/github_username/repo_name.svg?style=for-the-badge\n[contributors-url]: https://github.com/github_username/repo_name/graphs/contributors\n[forks-shield]: https://img.shields.io/github/forks/github_username/repo_name.svg?style=for-the-badge\n[forks-url]: https://github.com/github_username/repo_name/network/members\n[stars-shield]: https://img.shields.io/github/stars/github_username/repo_name.svg?style=for-the-badge\n[stars-url]: https://github.com/github_username/repo_name/stargazers\n[issues-shield]: https://img.shields.io/github/issues/github_username/repo_name.svg?style=for-the-badge\n[issues-url]: https://github.com/github_username/repo_name/issues\n[license-shield]: https://img.shields.io/github/license/github_username/repo_name.svg?style=for-the-badge\n[license-url]: https://github.com/github_username/repo_name/blob/master/LICENSE.txt\n[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555\n[linkedin-url]: https://linkedin.com/in/linkedin_username\n[product-screenshot]: images/screenshot.png',
    'author': 'Ahmed Kamel',
    'author_email': 'ahmedk@zadgroup.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
